require 'soar_idm/soar_idm'

module Soar
  module Registry
    module Identity
      module Provider
        module Customer
          class ClientNumber < SoarIdm::IdmApi

            ##
            # @param [Soar::Registry::Directory] directory
            # @param [String] fetch_index
            # @param [String] search_index
            ##
            def initialize(directory:, fetch_index: , search_index: )
              @directory = directory
              @fetch_index = fetch_index
              @search_index = search_index
            end

            ##
            # @param [String] client_number
            #   a client_number that uniquely identifies an identity
            # @return [Hash] an identity
            ##
            def calculate_identities(client_number)
              return @identities if not @identities.nil?
              entries = @directory.search(@search_index, client_number)
              @identities = entries.empty? ? [] : [entries[0]]
              return @identities
            end

            ##
            # @param [Hash] identity
            # @return [Array] list of identifiers
            ##
            def calculate_identifiers(identity)
              indexes = @directory.index
              identifiers = []
              indexes.each { |index| 
                identifiers << identity[index]
              }
              identifiers.compact
            end

            ##
            # @param [Hash] identity
            # @return [Array] list of roles
            def calculate_roles(identity)
              raise NotImplementedError
            end

            ## 
            # @param [Hash] identity
            # @param [String] role
            # @return [Hash] A hash of attributes 
            def calculate_attributes(identity, role)
              raise NotImplementedError
            end 

            ##
            # @param [Hash] identity
            # @return [Hash] Hash of attributes keyed by role
            def calculate_all_attributes(identity)
              raise NotImplementedError
            end


          end
        end
      end
    end
  end
end
