require 'soar_idm/soar_idm'

module Soar
  module Registry
    module Identity
      module Provider
        module Staff
          class Email < SoarIdm::IdmApi

            ##
            # @param [Soar::Registry::Directory] directory
            ##
            def initialize(directory:, fetch_index:, search_index:)
              @directory = directory
              @fetch_index = fetch_index
              @search_index = search_index
            end

            ##
            # @param [String] email
            #   an email address that uniquely identifies an identity
            # @return [Hash] an identity
            ##
            def calculate_identities(email)
              return @identities if not @identities.nil?
              entries = @directory.search(@search_index, email)
              @identities = entries.empty? ? [] : [entries[0]]
              return @identities
            end

            ##
            # @param [Hash] identity
            # @return [Array] list of identifiers
            ##
            def calculate_identifiers(identity)
              indexes = @directory.index
              identifiers = []
              indexes.each { |index| 
                identifiers << identity[index]
              }
              identifiers
            end

            ##
            # @param [Hash] identity
            # @return [Array] list of roles
            def calculate_roles(identity)
              raise NotImplementedError
            end

            ## 
            # @param [Hash] identity
            # @param [String] role
            # @return [Hash] A hash of attributes 
            def calculate_attributes(identity, role)
              raise NotImplementedError
            end 

            ##
            # @param [Hash] identity
            # @return [Hash] Hash of attributes keyed by role
            def calculate_all_attributes(identity)
              identity
            end


          end
        end
      end
    end
  end
end
